@@ -57,7 +57,7 @@ XCursorTheme::XCursorTheme(const QDir &themeDir)
                 sizeList.append(images->images[i]->size);
         };
         XcursorImagesDestroy(images);
-        qSort(sizeList.begin(), sizeList.end());
+        std::sort(sizeList.begin(), sizeList.end());
         m_availableSizes = sizeList;
     }
     if (!sizeList.isEmpty())
